Skip to content

log

View container logs for an app.

Usage

sh
mithrandir log [options] <app> [service]

Arguments

ArgumentDescription
appRequired. App name to view logs for
serviceService name for multi-container apps (e.g., backend, db)

Flags

FlagDescription
--follow, -fFollow log output in real time
--tail, -nNumber of lines to show from the end (e.g., --tail 100)
--since, -sShow logs since a timestamp or relative time (e.g., --since 1h, --since 2024-01-01)

Examples

sh
# Show last 50 lines of Sonarr logs
mithrandir log --tail 50 sonarr

# Follow Pi-hole logs in real time
mithrandir log --follow pihole

# Show Jellyfin logs from the last 2 hours
mithrandir log --since 2h jellyfin

# Show AdventureLog backend logs
mithrandir log adventurelog backend

# Follow Immich postgres logs
mithrandir log --follow immich postgres

Multi-container apps

For apps with multiple containers, you must specify a service name. Running mithrandir log <app> without a service will list the available services:

AppServices
AdventureLogfrontend, backend, db
Immichserver, machine-learning, redis, postgres
Sureweb, worker, redis, postgres
AFFiNEserver, migration-job, redis, postgres
Penpotfrontend, backend, exporter, postgres, valkey, mailcatch

Notes

  • Requires root privileges
  • Press Ctrl+C to stop following logs