graph
Show the inter-app dependency tree.
Usage
sh
mithrandir graphDoes not require root privileges.
Output
Displays a color-coded dependency graph organized into three sections:
Media Pipeline
Shows the data flow through the Arr stack:
Prowlarr ───► Radarr ───► qBittorrent ───► /data/media/movies ───► Jellyfin
│ Sonarr ───► qBittorrent ───► /data/media/tv ───► Jellyfin
└──────► Lidarr ───► qBittorrent ───► /data/media/music ───► Navidrome
FlareSolverr ───► Prowlarr (CAPTCHA solving, auto-installed with Prowlarr)
Bazarr ───► Radarr, Sonarr (subtitle management)
Seerr ───► Radarr, Sonarr, Jellyfin (media requests & discovery)
Profilarr ───► Radarr, Sonarr (quality profile management)Recommended Installation Order
The suggested order for installing the full media stack, based on dependencies:
- qBittorrent (download client)
- Prowlarr (indexer manager)
- Radarr (movies)
- Sonarr (TV)
- Lidarr (music)
- Bazarr (subtitles, optional)
- Jellyfin (media server)
- Navidrome (music server)
- Seerr (media requests, optional)
- Profilarr (quality profiles, optional)
Network & Security
DuckDNS ───► Caddy ───► all apps with ports (wildcard HTTPS reverse proxy)
Caddy ───► Vaultwarden (HTTPS required)
Pi-hole (standalone DNS, optional wildcard DNS for Caddy)Standalone
Apps with no dependencies that can be installed independently:
Home Assistant, Immich, Gatus, Homarr, WireGuard, Excalidraw, Omni Tools, Open WebUI, Actual Budget, Sure, AFFiNE, n8n, Penpot
Notes
- Installed apps are shown in green, uninstalled apps are dimmed
- The graph reads
.envto determine which apps are installed - Use
mithrandir install mediato install the entire media stack at once