install
Install a system component, app, or predefined app stack.
Usage
sh
mithrandir install <target>Arguments
| Argument | Description |
|---|---|
target | Required. What to install — see targets below |
Targets
System Components
| Target | Description |
|---|---|
docker | Install Docker engine on the host (includes swap configuration) |
backup | Install rclone and the backup systemd timer for scheduled backups |
https | Install Caddy as a wildcard HTTPS reverse proxy using DuckDNS DNS-01 challenge |
firewall | Install UFW firewall with ufw-docker for Docker-aware port control |
Stacks
Install a predefined group of apps in one command. Already-installed apps are skipped automatically.
| Stack | Apps |
|---|---|
media | qBittorrent, Prowlarr, Radarr, Sonarr, Bazarr, Seerr, Jellyfin, Navidrome, Lidarr, Audiobookshelf, Immich |
media-movies-tv | qBittorrent, Prowlarr, Radarr, Sonarr, Bazarr, Seerr, Jellyfin |
media-audio | Navidrome, Lidarr, Audiobookshelf, qBittorrent |
media-pictures | Immich |
media-games | RetroAssembly |
security | Caddy (HTTPS reverse proxy), Pi-hole (DNS) |
Examples:
sh
mithrandir install media-movies-tv # Install the full movie & TV stack
mithrandir install security # Install Caddy and Pi-holeApps
Any app name from the registry can be used as a target. Available apps:
actualbudget, sure, homarr, pihole, homeassistant, jellyfin, jellyseerr, sonarr, radarr, lidarr, prowlarr, qbittorrent, navidrome, duckdns, wireguard, vaultwarden, flaresolverr, omni-tools, excalidraw, openwebui, immich, gatus, bazarr, seerr, trip, retroassembly
Notes
- Requires root privileges
install httpsrequires DuckDNS to be installed and running first, and builds a custom Caddy Docker image with thecaddy-dns/duckdnsmodule- Vaultwarden requires
ENABLE_HTTPS=truein.env - Some apps install companion apps automatically (e.g.,
jellyseerrinstallsjellyfin) - Stack installs skip apps that are already installed and include companion apps automatically
- The
securitystack skips Caddy — install it separately withmithrandir install https